@@ -1,7 +1,6 @@
 from .private import private_websocket_connection
 from .public import public_websocket_connection
 from .reconnect import retry_with_backoff
-from .status import *
 from .request_response import wait_for_response
 from .http import prepare_request, send_request
 
@@ -10,4 +9,6 @@ __all__ = [
     "public_websocket_connection",
     "private_websocket_connection",
     "retry_with_backoff",
+    "prepare_request",
+    "send_request",
 ]
