@@ -1,13 +1,16 @@
-from typing import Callable, Dict, List, cast, overload
+from typing import Callable, Dict, List, cast
 
 from reactivex import Observable, compose, operators, timer
 
-from bittrade_cryptodotcom_websocket.connection.bundle import WebsocketStatusBundle
 
-from ..connection.connection_operators import filter_socket_status_only
-from ..connection.generic import WEBSOCKET_MESSAGE, WEBSOCKET_STATUS, WebsocketBundle
-from ..connection.status import Status
-from ..models import CryptodotcomResponseMessage, EnhancedWebsocket
+from ..connection.generic import WEBSOCKET_MESSAGE
+from ..models.status import Status
+from ..models import (
+    CryptodotcomResponseMessage,
+    EnhancedWebsocket,
+    WebsocketBundle,
+    WebsocketStatusBundle,
+)
 
 
 def _is_message(message: WebsocketBundle) -> bool:
