@@ -10,7 +10,7 @@ import websocket
 from .request import CryptodotcomRequestMessage
 
 logger = getLogger(__name__)
-raw_logger = getLogger("bittrade_cryptodotcom_websocket.connection.generic.raw")
+raw_logger = getLogger("bittrade_cryptodotcom_websocket.raw_socket.sent")
 
 
 class EnhancedWebsocket:
@@ -39,7 +39,8 @@ class EnhancedWebsocket:
         if "params" in as_dict and not as_dict["params"]:
             del as_dict["params"]
         if not as_dict["id"]:
-            as_dict["id"] = self._id
+            # We use dict constructor here as convenience so that id is first key which makes logging better
+            as_dict = dict(id=self._id, **as_dict)
         as_bytes = orjson.dumps(as_dict)
         return as_dict["id"], as_bytes
 
@@ -50,6 +51,7 @@ class EnhancedWebsocket:
 
         def send_():
             logger.debug("[SOCKET][BYTES] Sending json to socket: %s", as_bytes)
+            raw_logger.debug(as_bytes.decode())
             self.socket.send(as_bytes)
 
         return message_id, reactivex.from_callable(send_)
@@ -57,7 +59,7 @@ class EnhancedWebsocket:
     def send_json(self, message: dict):
         message_id, as_bytes = self.prepare_request(message)
         logger.debug("[SOCKET] Sending json to socket: %s", as_bytes)
-        raw_logger.debug("<== %s", as_bytes)
+        raw_logger.debug(as_bytes.decode())
         self.socket.send(as_bytes)
         return message_id
 
